{
    "cwlVersion": "v1.0",
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#snakemake-job",
            "label": "Snakemake job executor",
            "hints": [
                {
                    "dockerPull": "snakemake/snakemake:v5.7.0",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "snakemake",
            "requirements": {
                "ResourceRequirement": {
                    "coresMin": "$(inputs.cores)"
                }
            },
            "arguments": [
                "--force",
                "--keep-target-files",
                "--keep-remote",
                "--force-use-threads",
                "--wrapper-prefix",
                "https://github.com/snakemake/snakemake-wrappers/raw/",
                "--notemp",
                "--quiet",
                "--use-conda",
                "--no-hooks",
                "--nolock",
                "--mode",
                "1"
            ],
            "inputs": {
                "snakefile": {
                    "type": "File",
                    "default": {
                        "class": "File",
                        "location": "vpipe.snake"
                    },
                    "inputBinding": {
                        "prefix": "--snakefile"
                    }
                },
                "sources": {
                    "type": "File[]",
                    "default": [
                        {
                            "class": "File",
                            "location": "rules/common.smk"
                        },
                        {
                            "class": "File",
                            "location": "rules/quality_assurance.smk"
                        },
                        {
                            "class": "File",
                            "location": "rules/align.smk"
                        },
                        {
                            "class": "File",
                            "location": "rules/mafs.smk"
                        },
                        {
                            "class": "File",
                            "location": "vpipe.snake"
                        },
                        {
                            "class": "File",
                            "location": "rules/clean.smk"
                        }
                    ]
                },
                "cores": {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "prefix": "--cores"
                    }
                },
                "rules": {
                    "type": "string[]?",
                    "inputBinding": {
                        "prefix": "--allowed-rules"
                    }
                },
                "input_files": {
                    "type": "File[]",
                    "default": []
                },
                "target_files": {
                    "type": "string[]?",
                    "inputBinding": {
                        "position": 0
                    }
                }
            },
            "outputs": {
                "output_files": {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "$(inputs.target_files)"
                    }
                }
            }
        },
        {
            "class": "Workflow",
            "requirements": {
                "InlineJavascriptRequirement": {},
                "MultipleInputFeatureRequirement": {}
            },
            "steps": [
                {
                    "run": "#snakemake-job",
                    "requirements": {
                        "InitialWorkDirRequirement": {
                            "listing": [
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'alignments', 'listing': [{'class': 'File', 'basename': 'REF_aln.bam', 'location': inputs.input_files[0].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'alignments', 'listing': [{'class': 'File', 'basename': 'full_aln.sam', 'location': inputs.input_files[1].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'alignments', 'listing': [{'class': 'File', 'basename': 'rejects.sam', 'location': inputs.input_files[2].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'references', 'listing': [{'class': 'File', 'basename': 'ref_ambig.fasta', 'location': inputs.input_files[3].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'references', 'listing': [{'class': 'File', 'basename': 'ref_majority.fasta', 'location': inputs.input_files[4].location}]}]}]}]})"
                                }
                            ]
                        }
                    },
                    "in": {
                        "cores": {
                            "default": 1
                        },
                        "target_files": {
                            "default": []
                        },
                        "rules": {
                            "default": [
                                "all"
                            ]
                        },
                        "input_files": {
                            "source": [
                                "#main/job-1/output_files",
                                "#main/job-2/output_files"
                            ],
                            "linkMerge": "merge_flattened"
                        }
                    },
                    "out": [
                        "output_files"
                    ],
                    "id": "#main/job-0"
                },
                {
                    "run": "#snakemake-job",
                    "requirements": {
                        "InitialWorkDirRequirement": {
                            "listing": [
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'references', 'listing': [{'class': 'File', 'basename': 'ALL_aln_ambig.fasta', 'location': inputs.input_files[0].location}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'references', 'listing': [{'class': 'File', 'basename': 'ALL_aln_majority.fasta', 'location': inputs.input_files[1].location}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'alignments', 'listing': [{'class': 'File', 'basename': 'full_aln.bam', 'location': inputs.input_files[2].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'alignments', 'listing': [{'class': 'File', 'basename': 'full_aln.bam.bai', 'location': inputs.input_files[3].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'alignments', 'listing': [{'class': 'File', 'basename': 'rejects.bam', 'location': inputs.input_files[4].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'alignments', 'listing': [{'class': 'File', 'basename': 'rejects.bam.bai', 'location': inputs.input_files[5].location}]}]}]}]})"
                                }
                            ]
                        }
                    },
                    "in": {
                        "cores": {
                            "default": 1
                        },
                        "target_files": {
                            "default": [
                                "samples/2VM-sim/20170904/alignments/REF_aln.bam"
                            ]
                        },
                        "rules": {
                            "default": [
                                "convert_to_ref"
                            ]
                        },
                        "input_files": {
                            "source": [
                                "#main/job-3/output_files",
                                "#main/job-4/output_files",
                                "#main/job-5/output_files",
                                "#main/job-6/output_files"
                            ],
                            "linkMerge": "merge_flattened"
                        }
                    },
                    "out": [
                        "output_files"
                    ],
                    "id": "#main/job-1"
                },
                {
                    "run": "#snakemake-job",
                    "requirements": {
                        "InitialWorkDirRequirement": {
                            "listing": [
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'references', 'listing': [{'class': 'File', 'basename': 'initial_consensus.fasta', 'location': inputs.input_files[0].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'preprocessed_data', 'listing': [{'class': 'File', 'basename': 'R1.fastq', 'location': inputs.input_files[1].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'preprocessed_data', 'listing': [{'class': 'File', 'basename': 'R2.fastq', 'location': inputs.input_files[2].location}]}]}]}]})"
                                }
                            ]
                        }
                    },
                    "in": {
                        "cores": {
                            "default": 1
                        },
                        "target_files": {
                            "default": [
                                "samples/2VM-sim/20170904/alignments/full_aln.sam",
                                "samples/2VM-sim/20170904/alignments/rejects.sam",
                                "samples/2VM-sim/20170904/references/ref_ambig.fasta",
                                "samples/2VM-sim/20170904/references/ref_majority.fasta"
                            ]
                        },
                        "rules": {
                            "default": [
                                "hmm_align"
                            ]
                        },
                        "input_files": {
                            "source": [
                                "#main/job-7/output_files",
                                "#main/job-8/output_files",
                                "#main/job-9/output_files"
                            ],
                            "linkMerge": "merge_flattened"
                        }
                    },
                    "out": [
                        "output_files"
                    ],
                    "id": "#main/job-2"
                },
                {
                    "run": "#snakemake-job",
                    "requirements": {
                        "InitialWorkDirRequirement": {
                            "listing": [
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'references', 'listing': [{'class': 'File', 'basename': 'HXB2.fasta', 'location': inputs.input_files[0].location}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'alignments', 'listing': [{'class': 'File', 'basename': 'full_aln.sam', 'location': inputs.input_files[1].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'alignments', 'listing': [{'class': 'File', 'basename': 'rejects.sam', 'location': inputs.input_files[2].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'references', 'listing': [{'class': 'File', 'basename': 'ref_ambig.fasta', 'location': inputs.input_files[3].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'references', 'listing': [{'class': 'File', 'basename': 'ref_majority.fasta', 'location': inputs.input_files[4].location}]}]}]}]})"
                                }
                            ]
                        }
                    },
                    "in": {
                        "cores": {
                            "default": 1
                        },
                        "target_files": {
                            "default": [
                                "references/ALL_aln_ambig.fasta"
                            ]
                        },
                        "rules": {
                            "default": [
                                "msa"
                            ]
                        },
                        "input_files": {
                            "source": [
                                "#main/input/job-3",
                                "#main/job-2/output_files"
                            ],
                            "linkMerge": "merge_flattened"
                        }
                    },
                    "out": [
                        "output_files"
                    ],
                    "id": "#main/job-3"
                },
                {
                    "run": "#snakemake-job",
                    "requirements": {
                        "InitialWorkDirRequirement": {
                            "listing": [
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'references', 'listing': [{'class': 'File', 'basename': 'HXB2.fasta', 'location': inputs.input_files[0].location}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'alignments', 'listing': [{'class': 'File', 'basename': 'full_aln.sam', 'location': inputs.input_files[1].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'alignments', 'listing': [{'class': 'File', 'basename': 'rejects.sam', 'location': inputs.input_files[2].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'references', 'listing': [{'class': 'File', 'basename': 'ref_ambig.fasta', 'location': inputs.input_files[3].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'references', 'listing': [{'class': 'File', 'basename': 'ref_majority.fasta', 'location': inputs.input_files[4].location}]}]}]}]})"
                                }
                            ]
                        }
                    },
                    "in": {
                        "cores": {
                            "default": 1
                        },
                        "target_files": {
                            "default": [
                                "references/ALL_aln_majority.fasta"
                            ]
                        },
                        "rules": {
                            "default": [
                                "msa"
                            ]
                        },
                        "input_files": {
                            "source": [
                                "#main/input/job-4",
                                "#main/job-2/output_files"
                            ],
                            "linkMerge": "merge_flattened"
                        }
                    },
                    "out": [
                        "output_files"
                    ],
                    "id": "#main/job-4"
                },
                {
                    "run": "#snakemake-job",
                    "requirements": {
                        "InitialWorkDirRequirement": {
                            "listing": [
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'alignments', 'listing': [{'class': 'File', 'basename': 'full_aln.sam', 'location': inputs.input_files[0].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'alignments', 'listing': [{'class': 'File', 'basename': 'rejects.sam', 'location': inputs.input_files[1].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'references', 'listing': [{'class': 'File', 'basename': 'ref_ambig.fasta', 'location': inputs.input_files[2].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'references', 'listing': [{'class': 'File', 'basename': 'ref_majority.fasta', 'location': inputs.input_files[3].location}]}]}]}]})"
                                }
                            ]
                        }
                    },
                    "in": {
                        "cores": {
                            "default": 1
                        },
                        "target_files": {
                            "default": [
                                "samples/2VM-sim/20170904/alignments/full_aln.bam",
                                "samples/2VM-sim/20170904/alignments/full_aln.bam.bai"
                            ]
                        },
                        "rules": {
                            "default": [
                                "sam2bam"
                            ]
                        },
                        "input_files": {
                            "source": [
                                "#main/job-2/output_files"
                            ],
                            "linkMerge": "merge_flattened"
                        }
                    },
                    "out": [
                        "output_files"
                    ],
                    "id": "#main/job-5"
                },
                {
                    "run": "#snakemake-job",
                    "requirements": {
                        "InitialWorkDirRequirement": {
                            "listing": [
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'alignments', 'listing': [{'class': 'File', 'basename': 'full_aln.sam', 'location': inputs.input_files[0].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'alignments', 'listing': [{'class': 'File', 'basename': 'rejects.sam', 'location': inputs.input_files[1].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'references', 'listing': [{'class': 'File', 'basename': 'ref_ambig.fasta', 'location': inputs.input_files[2].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'references', 'listing': [{'class': 'File', 'basename': 'ref_majority.fasta', 'location': inputs.input_files[3].location}]}]}]}]})"
                                }
                            ]
                        }
                    },
                    "in": {
                        "cores": {
                            "default": 1
                        },
                        "target_files": {
                            "default": [
                                "samples/2VM-sim/20170904/alignments/rejects.bam",
                                "samples/2VM-sim/20170904/alignments/rejects.bam.bai"
                            ]
                        },
                        "rules": {
                            "default": [
                                "sam2bam"
                            ]
                        },
                        "input_files": {
                            "source": [
                                "#main/job-2/output_files"
                            ],
                            "linkMerge": "merge_flattened"
                        }
                    },
                    "out": [
                        "output_files"
                    ],
                    "id": "#main/job-6"
                },
                {
                    "run": "#snakemake-job",
                    "requirements": {
                        "InitialWorkDirRequirement": {
                            "listing": [
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'references', 'listing': [{'class': 'File', 'basename': 'initial_aln_gap_removed.fasta', 'location': inputs.input_files[0].location}]})"
                                }
                            ]
                        }
                    },
                    "in": {
                        "cores": {
                            "default": 1
                        },
                        "target_files": {
                            "default": [
                                "samples/2VM-sim/20170904/references/initial_consensus.fasta"
                            ]
                        },
                        "rules": {
                            "default": [
                                "create_vicuna_initial"
                            ]
                        },
                        "input_files": {
                            "source": [
                                "#main/job-10/output_files"
                            ],
                            "linkMerge": "merge_flattened"
                        }
                    },
                    "out": [
                        "output_files"
                    ],
                    "id": "#main/job-7"
                },
                {
                    "run": "#snakemake-job",
                    "requirements": {
                        "InitialWorkDirRequirement": {
                            "listing": [
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'preprocessed_data', 'listing': [{'class': 'File', 'basename': 'R1.fastq.gz', 'location': inputs.input_files[0].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'preprocessed_data', 'listing': [{'class': 'File', 'basename': 'R2.fastq.gz', 'location': inputs.input_files[1].location}]}]}]}]})"
                                }
                            ]
                        }
                    },
                    "in": {
                        "cores": {
                            "default": 1
                        },
                        "target_files": {
                            "default": [
                                "samples/2VM-sim/20170904/preprocessed_data/R1.fastq"
                            ]
                        },
                        "rules": {
                            "default": [
                                "gunzip"
                            ]
                        },
                        "input_files": {
                            "source": [
                                "#main/job-11/output_files"
                            ],
                            "linkMerge": "merge_flattened"
                        }
                    },
                    "out": [
                        "output_files"
                    ],
                    "id": "#main/job-8"
                },
                {
                    "run": "#snakemake-job",
                    "requirements": {
                        "InitialWorkDirRequirement": {
                            "listing": [
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'preprocessed_data', 'listing': [{'class': 'File', 'basename': 'R1.fastq.gz', 'location': inputs.input_files[0].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'preprocessed_data', 'listing': [{'class': 'File', 'basename': 'R2.fastq.gz', 'location': inputs.input_files[1].location}]}]}]}]})"
                                }
                            ]
                        }
                    },
                    "in": {
                        "cores": {
                            "default": 1
                        },
                        "target_files": {
                            "default": [
                                "samples/2VM-sim/20170904/preprocessed_data/R2.fastq"
                            ]
                        },
                        "rules": {
                            "default": [
                                "gunzip"
                            ]
                        },
                        "input_files": {
                            "source": [
                                "#main/job-11/output_files"
                            ],
                            "linkMerge": "merge_flattened"
                        }
                    },
                    "out": [
                        "output_files"
                    ],
                    "id": "#main/job-9"
                },
                {
                    "run": "#snakemake-job",
                    "requirements": {
                        "InitialWorkDirRequirement": {
                            "listing": [
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'references', 'listing': [{'class': 'File', 'basename': 'vicuna_consensus.fasta', 'location': inputs.input_files[0].location}]}]}]}]})"
                                }
                            ]
                        }
                    },
                    "in": {
                        "cores": {
                            "default": 1
                        },
                        "target_files": {
                            "default": [
                                "references/initial_aln_gap_removed.fasta"
                            ]
                        },
                        "rules": {
                            "default": [
                                "initial_vicuna_msa"
                            ]
                        },
                        "input_files": {
                            "source": [
                                "#main/job-12/output_files"
                            ],
                            "linkMerge": "merge_flattened"
                        }
                    },
                    "out": [
                        "output_files"
                    ],
                    "id": "#main/job-10"
                },
                {
                    "run": "#snakemake-job",
                    "requirements": {
                        "InitialWorkDirRequirement": {
                            "listing": [
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'extracted_data', 'listing': [{'class': 'File', 'basename': 'R1.fastq', 'location': inputs.input_files[0].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'extracted_data', 'listing': [{'class': 'File', 'basename': 'R2.fastq', 'location': inputs.input_files[1].location}]}]}]}]})"
                                }
                            ]
                        }
                    },
                    "in": {
                        "cores": {
                            "default": 1
                        },
                        "target_files": {
                            "default": [
                                "samples/2VM-sim/20170904/preprocessed_data/R1.fastq.gz",
                                "samples/2VM-sim/20170904/preprocessed_data/R2.fastq.gz"
                            ]
                        },
                        "rules": {
                            "default": [
                                "preprocessing"
                            ]
                        },
                        "input_files": {
                            "source": [
                                "#main/job-13/output_files",
                                "#main/job-14/output_files"
                            ],
                            "linkMerge": "merge_flattened"
                        }
                    },
                    "out": [
                        "output_files"
                    ],
                    "id": "#main/job-11"
                },
                {
                    "run": "#snakemake-job",
                    "requirements": {
                        "InitialWorkDirRequirement": {
                            "listing": [
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'references', 'listing': [{'class': 'File', 'basename': 'HXB2.fasta', 'location': inputs.input_files[0].location}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'preprocessed_data', 'listing': [{'class': 'File', 'basename': 'R1.fastq', 'location': inputs.input_files[1].location}]}]}]}]})"
                                },
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'preprocessed_data', 'listing': [{'class': 'File', 'basename': 'R2.fastq', 'location': inputs.input_files[2].location}]}]}]}]})"
                                }
                            ]
                        }
                    },
                    "in": {
                        "cores": {
                            "default": 1
                        },
                        "target_files": {
                            "default": [
                                "samples/2VM-sim/20170904/references/vicuna_consensus.fasta"
                            ]
                        },
                        "rules": {
                            "default": [
                                "initial_vicuna"
                            ]
                        },
                        "input_files": {
                            "source": [
                                "#main/input/job-12",
                                "#main/job-8/output_files",
                                "#main/job-9/output_files"
                            ],
                            "linkMerge": "merge_flattened"
                        }
                    },
                    "out": [
                        "output_files"
                    ],
                    "id": "#main/job-12"
                },
                {
                    "run": "#snakemake-job",
                    "requirements": {
                        "InitialWorkDirRequirement": {
                            "listing": [
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'raw_data', 'listing': [{'class': 'File', 'basename': '2VirusMix_simulated_R1.fastq', 'location': inputs.input_files[0].location}]}]}]}]})"
                                }
                            ]
                        }
                    },
                    "in": {
                        "cores": {
                            "default": 1
                        },
                        "target_files": {
                            "default": [
                                "samples/2VM-sim/20170904/extracted_data/R1.fastq"
                            ]
                        },
                        "rules": {
                            "default": [
                                "extract"
                            ]
                        },
                        "input_files": {
                            "source": [
                                "#main/job-15/output_files"
                            ],
                            "linkMerge": "merge_flattened"
                        }
                    },
                    "out": [
                        "output_files"
                    ],
                    "id": "#main/job-13"
                },
                {
                    "run": "#snakemake-job",
                    "requirements": {
                        "InitialWorkDirRequirement": {
                            "listing": [
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'raw_data', 'listing': [{'class': 'File', 'basename': '2VirusMix_simulated_R2.fastq', 'location': inputs.input_files[0].location}]}]}]}]})"
                                }
                            ]
                        }
                    },
                    "in": {
                        "cores": {
                            "default": 1
                        },
                        "target_files": {
                            "default": [
                                "samples/2VM-sim/20170904/extracted_data/R2.fastq"
                            ]
                        },
                        "rules": {
                            "default": [
                                "extract"
                            ]
                        },
                        "input_files": {
                            "source": [
                                "#main/job-16/output_files"
                            ],
                            "linkMerge": "merge_flattened"
                        }
                    },
                    "out": [
                        "output_files"
                    ],
                    "id": "#main/job-14"
                },
                {
                    "run": "#snakemake-job",
                    "requirements": {
                        "InitialWorkDirRequirement": {
                            "listing": [
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'raw_data', 'listing': [{'class': 'File', 'basename': '2VirusMix_simulated_R1.fastq.gz', 'location': inputs.input_files[0].location}]}]}]}]})"
                                }
                            ]
                        }
                    },
                    "in": {
                        "cores": {
                            "default": 1
                        },
                        "target_files": {
                            "default": [
                                "samples/2VM-sim/20170904/raw_data/2VirusMix_simulated_R1.fastq"
                            ]
                        },
                        "rules": {
                            "default": [
                                "gunzip"
                            ]
                        },
                        "input_files": {
                            "source": [
                                "#main/input/job-15"
                            ],
                            "linkMerge": "merge_flattened"
                        }
                    },
                    "out": [
                        "output_files"
                    ],
                    "id": "#main/job-15"
                },
                {
                    "run": "#snakemake-job",
                    "requirements": {
                        "InitialWorkDirRequirement": {
                            "listing": [
                                {
                                    "writable": true,
                                    "entry": "$({'class': 'Directory', 'basename': 'samples', 'listing': [{'class': 'Directory', 'basename': '2VM-sim', 'listing': [{'class': 'Directory', 'basename': '20170904', 'listing': [{'class': 'Directory', 'basename': 'raw_data', 'listing': [{'class': 'File', 'basename': '2VirusMix_simulated_R2.fastq.gz', 'location': inputs.input_files[0].location}]}]}]}]})"
                                }
                            ]
                        }
                    },
                    "in": {
                        "cores": {
                            "default": 1
                        },
                        "target_files": {
                            "default": [
                                "samples/2VM-sim/20170904/raw_data/2VirusMix_simulated_R2.fastq"
                            ]
                        },
                        "rules": {
                            "default": [
                                "gunzip"
                            ]
                        },
                        "input_files": {
                            "source": [
                                "#main/input/job-16"
                            ],
                            "linkMerge": "merge_flattened"
                        }
                    },
                    "out": [
                        "output_files"
                    ],
                    "id": "#main/job-16"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "default": [
                        {
                            "class": "File",
                            "location": "references/HXB2.fasta"
                        }
                    ],
                    "id": "#main/input/job-3"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "default": [
                        {
                            "class": "File",
                            "location": "references/HXB2.fasta"
                        }
                    ],
                    "id": "#main/input/job-4"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "default": [
                        {
                            "class": "File",
                            "location": "references/HXB2.fasta"
                        }
                    ],
                    "id": "#main/input/job-12"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "default": [
                        {
                            "class": "File",
                            "location": "samples/2VM-sim/20170904/raw_data/2VirusMix_simulated_R1.fastq.gz"
                        }
                    ],
                    "id": "#main/input/job-15"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "default": [
                        {
                            "class": "File",
                            "location": "samples/2VM-sim/20170904/raw_data/2VirusMix_simulated_R2.fastq.gz"
                        }
                    ],
                    "id": "#main/input/job-16"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/job-0/output_files",
                    "id": "#main/output/job-0"
                }
            ],
            "id": "#main"
        }
    ]
}